Auto Create Input Provider Config Entry for Available MT Hardware (linux only). — Kivy v1.0.1-dev documentation

# Auto Create Input Provider Config Entry for Available MT Hardware (linux only).

Thanks to Marc Tardif for the probing code, taken from scan-for-mt-device.

The device discovery is done by this provider. However, the reading of input can be made by 2 other providers: hidinput or mtdev. mtdev is used prior to hidinput. For more information about mtdev, check `mtdev`.

Here is an example of auto creation

    [input]
    # using mtdev
    device_%(name)s = probesysfs,provider=mtdev
    # using hidinput
    device_%(name)s = probesysfs,provider=hidinput
    # using mtdev with a match on name
    device_%(name)s = probesysfs,provider=mtdev,match=acer

    # using hidinput with custom parameters to hidinput (all on one line)
    %(name)s = probesysfs,
        provider=hidinput,param=min_pressure=1,param=max_pressure=99

ProbeSysfs module will enumerate hardware from /sys/class/input device, and configure hardware with ABS_MT_POSITION_X capability.